<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Illuminate\Database\Eloquent\Factories\HasFactory;

class Item extends Model
{
    use HasFactory;
    use SoftDeletes;
    public $timestamps = true;
    protected $fillable = [
        'name_en',
        'name_ar',
        'unit',
    ];
    protected $dates        = ['deleted_at'];

    // many to many relationship between Items table and Products table
    public function products()
    {
        return $this->belongsToMany(Product::class,'products_items','item_id','product_id')
                    ->withPivot('mesurment')->wherePivotNull('deleted_at');
        // return $this->belongsToMany(Product::class,'products_items');
    }

    // many to many relationship between purchases table and items table
    public function purchases()
    {
        return $this->belongsToMany(Purchase::class,'purchases_items','item_id','purchase_id')
                    ->withPivot('mesurment','quantity','expire_date')->wherePivotNull('deleted_at');
    }

    // one to many relationship between Inventories table and Items table
    public function inventory()
    {
        return $this->belongsTo(Inventory::class,'item_id');
    }
}
