<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class Order extends Model
{
    use HasFactory;

    use SoftDeletes;

    protected $connection   = 'mysql';
    protected $table        = 'orders';
    protected $dates        = ['deleted_at'];

    // many to many relationship between ordes table and products table (third table is orders_items)
    public function products()
    {
        return $this->belongsToMany(Product::class,'orders_items','order_id','product_id')
                    ->withPivot('quantity','taxable_amount','total_amount','tax_amount')->wherePivotNull('deleted_at');
    }

    // one to one relationship between invoices table and orders table
    public function invoice(){
        // return $this->belongsTo(Invoice::class);
        return $this->hasOne(Invoice::class);
    }

    // one to many relationship between users table and orders table
    public function user_created_by()
    {
        return $this->belongsTo(User::class,'created_by');
    }

    public function user_modified_by()
    {
        return $this->belongsTo(User::class,'modified_by');
    }
}
